@@ -126,7 +126,11 @@ def upload_file(
             metadata[key[len(_FILE_METADATA_PREFIX) :]] = value
 
     return component_manager.get_file_manager().upload_file(
-        project_id, file_key, multipart_stream, metadata, content_type
+        project_id=project_id,
+        file_key=file_key,
+        file_stream=multipart_stream,  # type: ignore[arg-type]
+        metadata=metadata,
+        content_type=content_type,
     )
 
 
@@ -263,7 +267,7 @@ def download_file(
         file_stream,
         media_type=metadata.content_type,
         headers={
-            "Content-Disposition": f"attachment;filename={file_key}",
+            "Content-Disposition": f"attachment;filename={metadata.display_name}",
             "Content-Length": f"{file_len}",
         },
     )
