@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
-from typing import Any, Dict, Iterator, List, Optional, Tuple
+from typing import IO, Any, Dict, Iterator, List, Optional, Tuple
 
-from contaxy.schema import File, FileInput, FileStream, ResourceAction
+from contaxy.schema import File, FileInput, ResourceAction
 
 
 class FileOperations(ABC):
@@ -81,16 +81,16 @@ class FileOperations(ABC):
         self,
         project_id: str,
         file_key: str,
-        file_stream: FileStream,
+        file_stream: IO[bytes],
         metadata: Optional[Dict[str, str]] = None,
-        content_type: str = "application/octet-stream",
+        content_type: Optional[str] = None,
     ) -> File:
         """Upload a file.
 
         Args:
             project_id (str): Project ID associated with the file.
             file_key (str): Key of the file.
-            file_stream (FileStream): The actual file stream object.
+            file_stream (IO): The actual file stream object.
             metadata (Dict, optional): Additional key-value pairs of file meta data
             content_type (str, optional): The mime-type of the file. Defaults to "application/octet-stream".
 
